[lld] r361142 - [MIPS] Update mips-abs-got.s to not use .reloc

Fangrui Song via llvm-commits llvm-commits at lists.llvm.org
Mon May 20 04:17:02 PDT 2019


Author: maskray
Date: Mon May 20 04:17:02 2019
New Revision: 361142

URL: http://llvm.org/viewvc/llvm-project?rev=361142&view=rev
Log:
[MIPS] Update mips-abs-got.s to not use .reloc

As Simon Atanasyan suggested in D61563

Modified:
    lld/trunk/test/ELF/mips-abs-got.s

Modified: lld/trunk/test/ELF/mips-abs-got.s
URL: http://llvm.org/viewvc/llvm-project/lld/trunk/test/ELF/mips-abs-got.s?rev=361142&r1=361141&r2=361142&view=diff
==============================================================================
--- lld/trunk/test/ELF/mips-abs-got.s (original)
+++ lld/trunk/test/ELF/mips-abs-got.s Mon May 20 04:17:02 2019
@@ -4,7 +4,7 @@
 
 # RUN: llvm-mc -filetype=obj -triple=mips64-unknown-linux -o %t.o %s
 # RUN: echo "SECTIONS { \
 # RUN:          zero = 0; foo = 0x11004; bar = 0x22000; }" > %t.script
 # RUN: ld.lld --script %t.script -o %t.exe %t.o
 # RUN: llvm-readobj --mips-plt-got %t.exe | FileCheck %s
 
@@ -30,7 +30,7 @@
 
   .text
   nop
-  .reloc 0, R_MIPS_GOT_PAGE, 0
-  ld      $v0, %got_page(zero)($gp)
+  ld      $v0, %got_page(zero1)($gp)
+  ld      $v0, %got_page(zero2)($gp)
   ld      $v0, %got_page(foo)($gp)
   ld      $v0, %got_page(bar+0x10008)($gp)
@@ -4,7 +4,7 @@
 # RUN: llvm-mc -filetype=obj -triple=mips64-unknown-linux -o %t.o %s
 # RUN: echo "SECTIONS { \
-# RUN:          zero = 0; foo = 0x11004; bar = 0x22000; }" > %t.script
+# RUN:          zero1 = 0; zero2 = 0; foo = 0x11004; bar = 0x22000; }" > %t.script
 # RUN: ld.lld --script %t.script -o %t.exe %t.o
 # RUN: llvm-readobj --mips-plt-got %t.exe | FileCheck %s




More information about the llvm-commits mailing list